unit MainCont;

interface

uses
  ContSyncML, SyncMLBase,
  Forms,
  StdCtrls, Spin, Classes, Controls;

type
  TMainContForm = class(TForm)
    ConnectBtn: TButton;
    GroupBox1: TGroupBox;
    ContactsLB: TListBox;
    ConAddBtn: TButton;
    ConEditBtn: TButton;
    ConDeleteBtn: TButton;
    CheckBox1: TCheckBox;
    ProxyEd: TEdit;
    Label5: TLabel;
    PortEd: TSpinEdit;
    StoreBtn: TButton;
    Label1: TLabel;
    Label2: TLabel;
    Label6: TLabel;
    Label7: TLabel;
    UserNameEd: TEdit;
    PasswordEd: TEdit;
    ServerEd: TEdit;
    DSEd: TEdit;
    procedure ConnectBtnClick(Sender: TObject);
    procedure FormCreate(Sender: TObject);
    procedure FormDestroy(Sender: TObject);
    procedure ConEditBtnClick(Sender: TObject);
    procedure ConAddBtnClick(Sender: TObject);
    procedure ConDeleteBtnClick(Sender: TObject);
    procedure ContactsLBDblClick(Sender: TObject);
    procedure CheckBox1Click(Sender: TObject);
    procedure StoreBtnClick(Sender: TObject);
    procedure ContactsLBClick(Sender: TObject);
  private
    procedure UpdateContacts;
    procedure UpdateConButtons;
  end;

var
  MainContForm: TMainContForm;

implementation

uses EditCont;

{$R *.dfm}

var
  SMLContacts: TSMLContacts;

procedure TMainContForm.ConnectBtnClick(Sender: TObject);
begin
  ConAddBtn.Enabled := False;
  ContactsLB.Items.Clear;
  Application.ProcessMessages;
  if not CheckBox1.Checked then
  begin
    SMLContacts.ProxyServer := ProxyEd.Text;
    SMLContacts.ProxyPort := PortEd.Value;
  end
  else
  begin
    SMLContacts.ProxyServer := '';
    SMLContacts.ProxyPort := 0;
  end;
  SMLContacts.BaseURL := ServerEd.Text;
  SMLContacts.UserName := UserNameEd.Text;
  SMLContacts.Password := PasswordEd.Text;
  SMLContacts.DataSource := DSEd.Text;
  SMLContacts.Load;
  ConAddBtn.Enabled := True;
  UpdateContacts;
  ConnectBtn.Caption := 'Refresh';
  StoreBtn.Enabled := False;
  UpdateConButtons;
end;

procedure TMainContForm.FormCreate(Sender: TObject);
begin
  SMLContacts := TSMLContacts.Create;
//  SMLContacts.LogFileName := 'ContSyncML.log';
end;

procedure TMainContForm.FormDestroy(Sender: TObject);
begin
  SMLContacts.Free;
end;

procedure TMainContForm.UpdateConButtons;
begin
  ConEditBtn.Enabled := ContactsLB.ItemIndex >= 0;
  ConDeleteBtn.Enabled := ConEditBtn.Enabled;
end;

procedure TMainContForm.UpdateContacts;
var
  I: Integer;
begin
  with ContactsLB.Items, SMLContacts do
  begin
    Clear;
    for I := 0 to ContactsCount - 1 do
      if Contacts[I].LocalItemState <> isDeleted then
        AddObject(Contacts[I].Title, Contacts[I]);
  end;
  UpdateConButtons;
end;

procedure TMainContForm.ConEditBtnClick(Sender: TObject);
begin
  with ContactsLB, EditContForm do
  begin
    Contacts := SMLContacts;
    Contact := TSMLContact(Items.Objects[ItemIndex]);
    if ShowModal = mrOK then
    begin
      Items[ItemIndex] := Contact.Title;
      StoreBtn.Enabled := True;
    end;
  end;
end;

procedure TMainContForm.ConAddBtnClick(Sender: TObject);
begin
  with ContactsLB, EditContForm do
  begin
    Contacts := SMLContacts;
    Contact := nil;
    if ShowModal = mrOK then
    begin
      Items.AddObject(Contact.Title, Contact);
      StoreBtn.Enabled := True;
    end;
  end;
end;

procedure TMainContForm.ConDeleteBtnClick(Sender: TObject);
begin
  with ContactsLB do
  begin
    TSMLContact(Items.Objects[ItemIndex]).Delete;
    Items.Delete(ItemIndex);
    StoreBtn.Enabled := True;
  end;
end;

procedure TMainContForm.ContactsLBDblClick(Sender: TObject);
begin
  if ConEditBtn.Enabled then
    ConEditBtnClick(Sender);
end;

procedure TMainContForm.CheckBox1Click(Sender: TObject);
begin
  ProxyEd.Enabled := CheckBox1.Checked;
  PortEd.Enabled := ProxyEd.Enabled;
end;

procedure TMainContForm.StoreBtnClick(Sender: TObject);
begin
  SMLContacts.Store;
  StoreBtn.Enabled := False;
  UpdateContacts;
end;

procedure TMainContForm.ContactsLBClick(Sender: TObject);
begin
  UpdateConButtons;
end;

end.

